@@ -1,13 +1,10 @@
-# -*- coding: utf-8 -*-
-
-
 # Copyright (c) 2018, Moritz E. Beber
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
 # You may obtain a copy of the License at
 #
-#    http://www.apache.org/licenses/LICENSE-2.0
+#    https://www.apache.org/licenses/LICENSE-2.0
 #
 # Unless required by applicable law or agreed to in writing, software
 # distributed under the License is distributed on an "AS IS" BASIS,
@@ -19,13 +16,8 @@
 """Create top level imports."""
 
 
-from __future__ import absolute_import
-
 __author__ = "Moritz E. Beber"
 __email__ = "midnighter@posteo.net"
-from ._version import get_versions
 
-__version__ = get_versions()["version"]
-del get_versions
 
-from depinfo.info import *
+from .info import *
