@@ -1,13 +1,10 @@
-# -*- coding: utf-8 -*-
-
-
 # Copyright (c) 2018, Moritz E. Beber
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
 # You may obtain a copy of the License at
 #
-#    http://www.apache.org/licenses/LICENSE-2.0
+#    https://www.apache.org/licenses/LICENSE-2.0
 #
 # Unless required by applicable law or agreed to in writing, software
 # distributed under the License is distributed on an "AS IS" BASIS,
@@ -19,18 +16,17 @@
 """Verify the expected functionality of dependency information."""
 
 
-from __future__ import absolute_import
-
 import platform
+from typing import Dict
 
 import pytest
 
-import depinfo.info as depi
+import depinfo
 
 
-def test_get_sys_info():
+def test_get_sys_info() -> None:
     """Expect correct platform information."""
-    blob = depi.get_sys_info()
+    blob = depinfo.get_sys_info()
     assert "OS" in blob
     assert "OS-release" in blob
     assert "Python" in blob
@@ -39,14 +35,13 @@ def test_get_sys_info():
     assert blob["Python"] == platform.python_version()
 
 
-def test_get_pkg_info():
+def test_get_pkg_info() -> None:
     """Expect minimal package dependencies."""
-    blob = depi.get_pkg_info("depinfo")
+    blob = depinfo.get_pkg_info("depinfo")
     assert "depinfo" in blob
     assert "pip" in blob
     assert "setuptools" in blob
     assert "wheel" in blob
-    assert "pipdeptree" in blob
 
 
 @pytest.mark.parametrize(
@@ -56,16 +51,16 @@ def test_get_pkg_info():
         ({"pip": "10.0.0", "wheel": "0.5"}, "pip   10.0.0\nwheel    0.5\n"),
     ],
 )
-def test_print_info(capsys, blob, output):
+def test_print_info(capsys, blob: Dict[str, str], output: str) -> None:
     """Expect stdout in order and correctly formatted."""
-    depi.print_info(blob)
+    depinfo.print_info(blob)
     captured = capsys.readouterr()
     assert captured.out == output
 
 
-def test_print_dependencies(capsys):
+def test_print_dependencies(capsys) -> None:
     """Expect all printed information in order."""
-    depi.print_dependencies("depinfo")
+    depinfo.print_dependencies("depinfo")
     captured = capsys.readouterr()
     lines = captured.out.split("\n")
     assert lines[1].startswith("System Information")
@@ -76,16 +71,15 @@ def test_print_dependencies(capsys):
 
     assert lines[7].startswith("Package Versions")
     assert lines[8].startswith("================")
-    assert lines[9].startswith("depinfo")
-    assert lines[10].startswith("pip")
-    assert lines[11].startswith("pipdeptree")
-    assert lines[12].startswith("setuptools")
-    assert lines[13].startswith("wheel")
+    assert any(line.startswith("depinfo") for line in lines[9:])
+    assert any(line.startswith("pip") for line in lines[9:])
+    assert any(line.startswith("setuptools") for line in lines[9:])
+    assert any(line.startswith("wheel") for line in lines[9:])
 
 
-def test_show_versions(capsys):
+def test_show_versions(capsys) -> None:
     """Expect all printed information in order."""
-    depi.show_versions()
+    depinfo.show_versions()
     captured = capsys.readouterr()
     lines = captured.out.split("\n")
     assert lines[1].startswith("System Information")
@@ -96,8 +90,7 @@ def test_show_versions(capsys):
 
     assert lines[7].startswith("Package Versions")
     assert lines[8].startswith("================")
-    assert lines[9].startswith("depinfo")
-    assert lines[10].startswith("pip")
-    assert lines[11].startswith("pipdeptree")
-    assert lines[12].startswith("setuptools")
-    assert lines[13].startswith("wheel")
+    assert any(line.startswith("depinfo") for line in lines[9:])
+    assert any(line.startswith("pip") for line in lines[9:])
+    assert any(line.startswith("setuptools") for line in lines[9:])
+    assert any(line.startswith("wheel") for line in lines[9:])
